@@ -58,10 +58,9 @@ static HANDLE hRtsynThread =NULL;
 extern "C"
 BOOL WINAPI DllMain(HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved ){
 	if (fdwReason == DLL_PROCESS_ATTACH){
-		InitializeCriticalSection(&mim_section);
 		DisableThreadLibraryCalls(hinstDLL);
 	}else if(fdwReason == DLL_PROCESS_DETACH){
-		DeleteCriticalSection(&mim_section);
+		;
 	}
 	return TRUE;    
 }
@@ -85,10 +84,17 @@ STDAPI DllUnregisterServer(void)
 
 
 DWORD WINAPI threadfunc2(LPVOID lpV);
+STDAPI_(LONG) DefDriverProc(DWORD dwDriverId, HDRVR hdrvr, UINT msg, LONG lParam1, LONG lParam2);
 
 STDAPI_(LONG) DriverProc(DWORD dwDriverId, HDRVR hdrvr, UINT msg, LONG lParam1, LONG lParam2){
  
 	switch(msg) {
+	case DRV_REMOVE:
+		DeleteCriticalSection(&mim_section);
+		return 1;
+	case DRV_LOAD:
+		InitializeCriticalSection(&mim_section);
+		return 1;
 	case DRV_CLOSE:
 	case DRV_CONFIGURE:
 	case DRV_DISABLE:
@@ -96,16 +102,16 @@ STDAPI_(LONG) DriverProc(DWORD dwDriverId, HDRVR hdrvr, UINT msg, LONG lParam1,
 	case DRV_EXITSESSION:
 	case DRV_FREE:
 	case DRV_INSTALL:
-	case DRV_LOAD:
 	case DRV_OPEN:
 	case DRV_POWER:
 	case DRV_QUERYCONFIGURE:
-	case DRV_REMOVE:
 	default:
 		return 1;
 		break;
+		return DefDriverProc(dwDriverId, hdrvr, msg, lParam1, lParam2);
+		break;
 	}
-	return 1;
+	return DefDriverProc(dwDriverId, hdrvr, msg, lParam1, lParam2);
 }
 
 HRESULT modGetCaps(PVOID capsPtr, DWORD capsSize) {
